| Interface | Description |
|---|---|
| TableSwitchGenerator |
A code generator for switch statements.
|
| Class | Description |
|---|---|
| AdviceAdapter |
A
MethodVisitor to insert before, after and around
advices in methods and constructors. |
| AnalyzerAdapter |
A
MethodVisitor that keeps track of stack map frame changes between
visitFrame calls. |
| CodeSizeEvaluator |
A
MethodVisitor that can be used to approximate method size. |
| GeneratorAdapter |
A
MethodVisitor with convenient methods to generate
code. |
| InstructionAdapter |
A
MethodVisitor providing a more detailed API to generate and
transform instructions. |
| LocalVariablesSorter |
A
MethodVisitor that renumbers local variables in their order of
appearance. |
| Method |
A named method descriptor.
|
| SerialVersionUIDAdder |
A
ClassVisitor that adds a serial version unique identifier to a
class if missing. |
| StaticInitMerger |
A
ClassVisitor that merges clinit methods into a single one. |
Copyright © 2017. All rights reserved.