public class FnInvokers extends Object
| Constructor and Description |
|---|
FnInvokers() |
| Modifier and Type | Method and Description |
|---|---|
static byte |
invokeB(IFn f0) |
static double |
invokeD(IFn f0) |
static byte |
invokeDB(IFn f0,
double a) |
static double |
invokeDD(IFn f0,
double a) |
static byte |
invokeDDB(IFn f0,
double a,
double b) |
static double |
invokeDDD(IFn f0,
double a,
double b) |
static float |
invokeDDF(IFn f0,
double a,
double b) |
static int |
invokeDDI(IFn f0,
double a,
double b) |
static long |
invokeDDL(IFn f0,
double a,
double b) |
static Object |
invokeDDO(IFn f0,
double a,
double b) |
static short |
invokeDDS(IFn f0,
double a,
double b) |
static float |
invokeDF(IFn f0,
double a) |
static int |
invokeDI(IFn f0,
double a) |
static long |
invokeDL(IFn f0,
double a) |
static byte |
invokeDLB(IFn f0,
double a,
long b) |
static double |
invokeDLD(IFn f0,
double a,
long b) |
static float |
invokeDLF(IFn f0,
double a,
long b) |
static int |
invokeDLI(IFn f0,
double a,
long b) |
static long |
invokeDLL(IFn f0,
double a,
long b) |
static Object |
invokeDLO(IFn f0,
double a,
long b) |
static short |
invokeDLS(IFn f0,
double a,
long b) |
static Object |
invokeDO(IFn f0,
double a) |
static byte |
invokeDOB(IFn f0,
double a,
Object b) |
static double |
invokeDOD(IFn f0,
double a,
Object b) |
static float |
invokeDOF(IFn f0,
double a,
Object b) |
static int |
invokeDOI(IFn f0,
double a,
Object b) |
static long |
invokeDOL(IFn f0,
double a,
Object b) |
static Object |
invokeDOO(IFn f0,
double a,
Object b) |
static short |
invokeDOS(IFn f0,
double a,
Object b) |
static short |
invokeDS(IFn f0,
double a) |
static float |
invokeF(IFn f0) |
static int |
invokeI(IFn f0) |
static long |
invokeL(IFn f0) |
static byte |
invokeLB(IFn f0,
long a) |
static double |
invokeLD(IFn f0,
long a) |
static byte |
invokeLDB(IFn f0,
long a,
double b) |
static double |
invokeLDD(IFn f0,
long a,
double b) |
static float |
invokeLDF(IFn f0,
long a,
double b) |
static int |
invokeLDI(IFn f0,
long a,
double b) |
static long |
invokeLDL(IFn f0,
long a,
double b) |
static Object |
invokeLDO(IFn f0,
long a,
double b) |
static short |
invokeLDS(IFn f0,
long a,
double b) |
static float |
invokeLF(IFn f0,
long a) |
static int |
invokeLI(IFn f0,
long a) |
static long |
invokeLL(IFn f0,
long a) |
static byte |
invokeLLB(IFn f0,
long a,
long b) |
static double |
invokeLLD(IFn f0,
long a,
long b) |
static float |
invokeLLF(IFn f0,
long a,
long b) |
static int |
invokeLLI(IFn f0,
long a,
long b) |
static long |
invokeLLL(IFn f0,
long a,
long b) |
static Object |
invokeLLO(IFn f0,
long a,
long b) |
static short |
invokeLLS(IFn f0,
long a,
long b) |
static Object |
invokeLO(IFn f0,
long a) |
static byte |
invokeLOB(IFn f0,
long a,
Object b) |
static double |
invokeLOD(IFn f0,
long a,
Object b) |
static float |
invokeLOF(IFn f0,
long a,
Object b) |
static int |
invokeLOI(IFn f0,
long a,
Object b) |
static long |
invokeLOL(IFn f0,
long a,
Object b) |
static Object |
invokeLOO(IFn f0,
long a,
Object b) |
static short |
invokeLOS(IFn f0,
long a,
Object b) |
static short |
invokeLS(IFn f0,
long a) |
static Object |
invokeO(IFn f0) |
static byte |
invokeOB(IFn f0,
Object a) |
static double |
invokeOD(IFn f0,
Object a) |
static byte |
invokeODB(IFn f0,
Object a,
double b) |
static double |
invokeODD(IFn f0,
Object a,
double b) |
static float |
invokeODF(IFn f0,
Object a,
double b) |
static int |
invokeODI(IFn f0,
Object a,
double b) |
static long |
invokeODL(IFn f0,
Object a,
double b) |
static Object |
invokeODO(IFn f0,
Object a,
double b) |
static short |
invokeODS(IFn f0,
Object a,
double b) |
static float |
invokeOF(IFn f0,
Object a) |
static int |
invokeOI(IFn f0,
Object a) |
static long |
invokeOL(IFn f0,
Object a) |
static byte |
invokeOLB(IFn f0,
Object a,
long b) |
static double |
invokeOLD(IFn f0,
Object a,
long b) |
static float |
invokeOLF(IFn f0,
Object a,
long b) |
static int |
invokeOLI(IFn f0,
Object a,
long b) |
static long |
invokeOLL(IFn f0,
Object a,
long b) |
static Object |
invokeOLO(IFn f0,
Object a,
long b) |
static short |
invokeOLS(IFn f0,
Object a,
long b) |
static Object |
invokeOO(IFn f0,
Object a) |
static byte |
invokeOOB(IFn f0,
Object a,
Object b) |
static double |
invokeOOD(IFn f0,
Object a,
Object b) |
static float |
invokeOOF(IFn f0,
Object a,
Object b) |
static int |
invokeOOI(IFn f0,
Object a,
Object b) |
static long |
invokeOOL(IFn f0,
Object a,
Object b) |
static Object |
invokeOOO(IFn f0,
Object a,
Object b) |
static Object |
invokeOOOO(IFn f0,
Object a,
Object b,
Object c) |
static Object |
invokeOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d) |
static Object |
invokeOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e) |
static Object |
invokeOOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e,
Object f) |
static Object |
invokeOOOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e,
Object f,
Object g) |
static Object |
invokeOOOOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e,
Object f,
Object g,
Object h) |
static Object |
invokeOOOOOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e,
Object f,
Object g,
Object h,
Object i) |
static Object |
invokeOOOOOOOOOOO(IFn f0,
Object a,
Object b,
Object c,
Object d,
Object e,
Object f,
Object g,
Object h,
Object i,
Object j) |
static short |
invokeOOS(IFn f0,
Object a,
Object b) |
static short |
invokeOS(IFn f0,
Object a) |
static short |
invokeS(IFn f0) |
public static long invokeL(IFn f0)
public static int invokeI(IFn f0)
public static short invokeS(IFn f0)
public static byte invokeB(IFn f0)
public static double invokeD(IFn f0)
public static float invokeF(IFn f0)
public static long invokeLL(IFn f0, long a)
public static long invokeDL(IFn f0, double a)
public static int invokeLI(IFn f0, long a)
public static int invokeDI(IFn f0, double a)
public static short invokeLS(IFn f0, long a)
public static short invokeDS(IFn f0, double a)
public static byte invokeLB(IFn f0, long a)
public static byte invokeDB(IFn f0, double a)
public static double invokeLD(IFn f0, long a)
public static double invokeDD(IFn f0, double a)
public static float invokeLF(IFn f0, long a)
public static float invokeDF(IFn f0, double a)
public static long invokeLLL(IFn f0, long a, long b)
public static long invokeDDL(IFn f0, double a, double b)
public static long invokeLDL(IFn f0, long a, double b)
public static long invokeDLL(IFn f0, double a, long b)
public static int invokeLLI(IFn f0, long a, long b)
public static int invokeDDI(IFn f0, double a, double b)
public static int invokeLDI(IFn f0, long a, double b)
public static int invokeDLI(IFn f0, double a, long b)
public static short invokeLLS(IFn f0, long a, long b)
public static short invokeDDS(IFn f0, double a, double b)
public static short invokeLDS(IFn f0, long a, double b)
public static short invokeDLS(IFn f0, double a, long b)
public static byte invokeLLB(IFn f0, long a, long b)
public static byte invokeDDB(IFn f0, double a, double b)
public static byte invokeLDB(IFn f0, long a, double b)
public static byte invokeDLB(IFn f0, double a, long b)
public static double invokeLLD(IFn f0, long a, long b)
public static double invokeDDD(IFn f0, double a, double b)
public static double invokeLDD(IFn f0, long a, double b)
public static double invokeDLD(IFn f0, double a, long b)
public static float invokeLLF(IFn f0, long a, long b)
public static float invokeDDF(IFn f0, double a, double b)
public static float invokeLDF(IFn f0, long a, double b)
public static float invokeDLF(IFn f0, double a, long b)
public static Object invokeOOOOOO(IFn f0, Object a, Object b, Object c, Object d, Object e)
public static Object invokeOOOOOOO(IFn f0, Object a, Object b, Object c, Object d, Object e, Object f)
public static Object invokeOOOOOOOO(IFn f0, Object a, Object b, Object c, Object d, Object e, Object f, Object g)
public static Object invokeOOOOOOOOO(IFn f0, Object a, Object b, Object c, Object d, Object e, Object f, Object g, Object h)
public static Object invokeOOOOOOOOOO(IFn f0, Object a, Object b, Object c, Object d, Object e, Object f, Object g, Object h, Object i)
Copyright © 2026. All rights reserved.