public final class LazySeq extends Obj implements ISeq, Sequential, List, IPending, IHashEq
| Modifier and Type | Method and Description |
|---|---|
void |
add(int index,
Object element) |
boolean |
add(Object o) |
boolean |
addAll(Collection c) |
boolean |
addAll(int index,
Collection c) |
void |
clear() |
ISeq |
cons(Object o) |
boolean |
contains(Object o) |
boolean |
containsAll(Collection c) |
int |
count() |
IPersistentCollection |
empty() |
boolean |
equals(Object o) |
boolean |
equiv(Object o) |
Object |
first() |
Object |
get(int index) |
int |
hashCode() |
int |
hasheq() |
int |
indexOf(Object o) |
boolean |
isEmpty() |
boolean |
isRealized() |
Iterator |
iterator() |
int |
lastIndexOf(Object o) |
ListIterator |
listIterator() |
ListIterator |
listIterator(int index) |
ISeq |
more() |
ISeq |
next() |
Object |
remove(int index) |
boolean |
remove(Object o) |
boolean |
removeAll(Collection c) |
boolean |
retainAll(Collection c) |
ISeq |
seq() |
Object |
set(int index,
Object element) |
int |
size() |
List |
subList(int fromIndex,
int toIndex) |
Object[] |
toArray() |
Object[] |
toArray(Object[] a) |
Obj |
withMeta(IPersistentMap meta) |
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitreplaceAll, sort, spliteratorparallelStream, removeIf, streampublic LazySeq(IFn f)
public Obj withMeta(IPersistentMap meta)
public int count()
count in interface IPersistentCollectionpublic ISeq cons(Object o)
cons in interface IPersistentCollectioncons in interface ISeqpublic IPersistentCollection empty()
empty in interface IPersistentCollectionpublic boolean equiv(Object o)
equiv in interface IPersistentCollectionpublic int hashCode()
public boolean equals(Object o)
public Object[] toArray()
toArray in interface CollectiontoArray in interface Listpublic boolean add(Object o)
add in interface Collectionadd in interface Listpublic boolean remove(Object o)
remove in interface Collectionremove in interface Listpublic boolean addAll(Collection c)
addAll in interface CollectionaddAll in interface Listpublic void clear()
clear in interface Collectionclear in interface Listpublic boolean retainAll(Collection c)
retainAll in interface CollectionretainAll in interface Listpublic boolean removeAll(Collection c)
removeAll in interface CollectionremoveAll in interface Listpublic boolean containsAll(Collection c)
containsAll in interface CollectioncontainsAll in interface Listpublic Object[] toArray(Object[] a)
toArray in interface CollectiontoArray in interface Listpublic int size()
size in interface Collectionsize in interface Listpublic boolean isEmpty()
isEmpty in interface CollectionisEmpty in interface Listpublic boolean contains(Object o)
contains in interface Collectioncontains in interface Listpublic Iterator iterator()
public int lastIndexOf(Object o)
lastIndexOf in interface Listpublic ListIterator listIterator()
listIterator in interface Listpublic ListIterator listIterator(int index)
listIterator in interface Listpublic boolean addAll(int index,
Collection c)
public boolean isRealized()
isRealized in interface IPendingCopyright © 2025. All rights reserved.